@@ -12,11 +12,11 @@ NLP::GATE::AnnotationSet - A class for representing GATE-like annotation sets
 
 =head1 VERSION
 
-Version 0.4
+Version 0.6
 
 =cut
 
-our $VERSION = '0.4';
+our $VERSION = '0.6';
 
 =head1 SYNOPSIS
 
@@ -397,7 +397,7 @@ You can also look for information at:
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
-L<http://annocpan.org/~JOHANNP/NLP-GATE-0.1/>
+L<http://annocpan.org/~JOHANNP/NLP-GATE/>
 
 =item * CPAN Ratings
 
@@ -409,7 +409,7 @@ L<http://rt.cpan.org/Public/Dist/Display.html?Name=NLP-GATE>
 
 =item * Search CPAN
 
-L<http://search.cpan.org/~johannp/NLP-GATE-0.1/>
+L<http://search.cpan.org/~johannp/NLP-GATE/>
 
 =back
 
