@@ -16,11 +16,11 @@ NLP::GATE::Document - Class for manipulating GATE-like documents
 
 =head1 VERSION
 
-Version 0.4
+Version 0.6
 
 =cut
 
-our $VERSION = '0.4';
+our $VERSION = '0.6';
 
 =head1 SYNOPSIS
 
@@ -561,7 +561,7 @@ You can also look for information at:
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
-L<http://annocpan.org/~JOHANNP/NLP-GATE-0.1/>
+L<http://annocpan.org/~JOHANNP/NLP-GATE/>
 
 =item * CPAN Ratings
 
@@ -573,7 +573,7 @@ L<http://rt.cpan.org/Public/Dist/Display.html?Name=NLP-GATE>
 
 =item * Search CPAN
 
-L<http://search.cpan.org/~johannp/NLP-GATE-0.1/>
+L<http://search.cpan.org/~johannp/NLP-GATE/>
 
 =back
 
